@@ -41,9 +41,6 @@ enum connman_property_id {
 	CONNMAN_PROPERTY_ID_IPV4_GATEWAY,
 	CONNMAN_PROPERTY_ID_IPV4_BROADCAST,
 	CONNMAN_PROPERTY_ID_IPV4_NAMESERVER,
-
-	CONNMAN_PROPERTY_ID_WIFI_SECURITY,
-	CONNMAN_PROPERTY_ID_WIFI_PASSPHRASE,
 };
 
 /**
